@@ -55,7 +55,6 @@ struct _GsmAppClass
                                      guchar  exit_code);
         void        (*died)         (GsmApp *app,
                                      int     signal);
-        void        (*registered)   (GsmApp *app);
 
         /* virtual methods */
         gboolean    (*impl_start)                     (GsmApp     *app,
@@ -75,6 +74,10 @@ struct _GsmAppClass
         const char *(*impl_get_app_id)                (GsmApp     *app);
         gboolean    (*impl_is_disabled)               (GsmApp     *app);
         gboolean    (*impl_is_conditionally_disabled) (GsmApp     *app);
+
+        gboolean    (*impl_save_to_keyfile)           (GsmApp     *app,
+                                                       GKeyFile   *keyfile,
+                                                       GError    **error);
 };
 
 typedef enum
@@ -118,7 +121,13 @@ gboolean         gsm_app_provides                       (GsmApp     *app,
 char           **gsm_app_get_provides                   (GsmApp     *app);
 gboolean         gsm_app_has_autostart_condition        (GsmApp     *app,
                                                          const char *condition);
-void             gsm_app_registered                     (GsmApp     *app);
+gboolean         gsm_app_get_registered                 (GsmApp     *app);
+void             gsm_app_set_registered                 (GsmApp     *app,
+                                                         gboolean  registered);
+
+gboolean         gsm_app_save_to_keyfile                (GsmApp    *app,
+                                                         GKeyFile  *keyfile,
+                                                         GError   **error);
 
 G_END_DECLS
 
