@@ -64,6 +64,7 @@ static const char * const variable_unsetlist[] = {
     "WAYLAND_DISPLAY",
     "WAYLAND_SOCKET",
     "GNOME_SHELL_SESSION_MODE",
+    "GNOME_SETUP_DISPLAY",
     NULL
 };
 
@@ -768,6 +769,36 @@ gsm_util_start_systemd_unit (const char  *unit,
 
         return TRUE;
 }
+
+gboolean
+gsm_util_systemd_reset_failed (GError **error)
+{
+        g_autoptr(GDBusConnection) connection = NULL;
+        g_autoptr(GVariant)        reply = NULL;
+        GError *bus_error = NULL;
+
+        connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, error);
+
+        if (connection == NULL)
+                return FALSE;
+
+        reply = g_dbus_connection_call_sync (connection,
+                                             "org.freedesktop.systemd1",
+                                             "/org/freedesktop/systemd1",
+                                             "org.freedesktop.systemd1.Manager",
+                                             "ResetFailed",
+                                             NULL,
+                                             NULL,
+                                             G_DBUS_CALL_FLAGS_NONE,
+                                             -1, NULL, &bus_error);
+
+        if (bus_error != NULL) {
+                g_propagate_error (error, bus_error);
+                return FALSE;
+        }
+
+        return TRUE;
+}
 #endif
 
 void
