@@ -349,7 +349,7 @@ systemd_leader_run(void)
         fifo_name = g_strdup_printf ("%s/gnome-session-leader-fifo",
                                      g_get_user_runtime_dir ());
         res = mkfifo (fifo_name, 0666);
-        if (res < 0 && errno != -EEXIST)
+        if (res < 0 && errno != EEXIST)
                 g_warning ("Error creating FIFO: %m");
 
         fifo_fd = g_open (fifo_name, O_WRONLY | O_CLOEXEC, 0666);
@@ -551,6 +551,16 @@ main (int argc, char **argv)
                         session_name = _gsm_manager_get_default_session (NULL);
                 }
 
+                /* Reset all failed units; we are going to start a lof ot things and
+                 * really do not want to run into errors because units have failed
+                 * in a previous session
+                 */
+                gsm_util_systemd_reset_failed (&error);
+                if (error) {
+                        g_warning ("Failed to reset failed state of units: %s", error->message);
+                        g_clear_error (&error);
+                }
+
                 /* We don't escape the name (i.e. we leave any '-' intact). */
                 gnome_session_target = g_strdup_printf ("gnome-session-%s@%s.target", session_type, session_name);
                 if (gsm_util_start_systemd_unit (gnome_session_target, "fail", &error)) {
@@ -599,6 +609,10 @@ main (int argc, char **argv)
 
         gsm_main ();
 
+#ifdef HAVE_SYSTEMD
+        gsm_util_export_user_environment (NULL);
+#endif
+
         g_clear_object (&manager);
         g_free (gl_renderer);
 
